@@ -17,22 +17,9 @@ may be implemented.  If the loading of this additional module fails we report no
 =cut
 
 
-=head1 AUTHOR
+=head1 METHODS
 
- Steve
- --
- http://www.steve.org.uk/
-
-=cut
-
-=head1 LICENSE
-
-Copyright (c) 2010-2012 by Steve Kemp.  All rights reserved.
-
-This module is free software;
-you can redistribute it and/or modify it under
-the same terms as Perl itself.
-The LICENSE file contains the full text of the license.
+Now follows documentation on the available methods.
 
 =cut
 
@@ -44,6 +31,8 @@ use warnings;
 package Slaughter::API::freebsd;
 
 
+our $VERSION = "3.0.2";
+
 
 
 #
@@ -52,14 +41,10 @@ package Slaughter::API::freebsd;
 use Slaughter::Packages::freebsd;
 
 
-=begin doc
+=head2 import
 
 Export all subs in this package into the main namespace.
 
-This is nasty.
-
-=end doc
-
 =cut
 
 sub import
@@ -88,21 +73,21 @@ sub import
 
 The InstallPackage primitive will allow you to install a system package.
 
-This method uses C<Slaughter::Packages::freebsd>.
+This method uses L<Slaughter::Packages::freebsd>.
 
 =for example begin
 
-  foreach my $package ( qw! bash tcsh ! )
-  {
-      if ( PackageInstalled( Package => $package ) )
-      {
-          print "$package installed\n";
-      }
-      else
-      {
-          InstallPackage( Package => $package );
-      }
-  }
+   foreach my $package ( qw! bash tcsh ! )
+   {
+       if ( PackageInstalled( Package => $package ) )
+       {
+           print "$package installed\n";
+       }
+       else
+       {
+           InstallPackage( Package => $package );
+       }
+   }
 
 =for example end
 
@@ -149,7 +134,7 @@ sub InstallPackage
 
 Test whether a given system package is installed.
 
-This method uses C<Slaughter::Packages::freebsd>.
+This method uses L<Slaughter::Packages::freebsd>.
 
 =for example begin
 
@@ -205,7 +190,7 @@ sub PackageInstalled
 
 Remove the specified system package from the system.
 
-This method uses C<Slaughter::Packages::freebsd>.
+This method uses L<Slaughter::Packages::freebsd>.
 
 =for example begin
 
@@ -320,3 +305,22 @@ sub UserCreate
 
 
 1;
+
+
+
+=head1 AUTHOR
+
+Steve Kemp <steve@steve.org.uk>
+
+=cut
+
+=head1 LICENSE
+
+Copyright (c) 2010-2014 by Steve Kemp.  All rights reserved.
+
+This module is free software;
+you can redistribute it and/or modify it under
+the same terms as Perl itself.
+The LICENSE file contains the full text of the license.
+
+=cut
